@@ -5,7 +5,7 @@ Usage::
     >>> result=query("select name from input.csv,heads.csv where native='usa'")
 """
 
-from .icecoal import query
+from .icecoal import query,escape
 from .utilfuns import setdel,getdel
 
-__all__=['query','setdel','getdel']
\ No newline at end of file
+__all__=['query','setdel','getdel','escape']
\ No newline at end of file
