@@ -52,8 +52,12 @@ exp_rules=[
         ["4",'=',"1",'operatorpush','opandop'],
         ["4",'other',"1",'pass','operator'],
         ["5",singlequote,"6",'','string'],
+        ["5",['\\'],"5.e",'',''],
+        ["5.e",'any',"5",'operandpush',''],
         ["5",'any',"5",'operandpush',''],
         ["5.1",doublequote,"6",'','string'],
+        ["5.1",['\\'],"5.1.e",'',''],
+        ["5.1.e",'any',"5.1",'operandpush',''],
         ["5.1",'any',"5.1",'operandpush',''],
         ["6",'=',"1",'operatorpush','operator'],
         ["6",'!',"8",'operatorpush',''],
@@ -146,9 +150,13 @@ rule=[
         ['24.2','any',"24",'pass',''],
     ['24',singlequote,"24.3",'push',''],
         ['24.3',singlequote,"24",'push',''],
+        ['24.3',['\\'],"24.3.e",'',''],
+        ['24.3.e','any',"24.3",'push',''],
         ['24.3','any',"24.3",'push',''],
     ['24',doublequote,"24.4",'push',''],
         ['24.4',doublequote,"24",'push',''],
+        ['24.4',['\\'],"24.4.e",'',''],
+        ['24.4.e','any',"24.4",'push',''],
         ['24.4','any',"24.4",'push',''],
     
     ['24',operator,"24",'push',''],
@@ -338,10 +346,14 @@ rule=[
     
     ['312',singlequote,"312.1",'',''],
     ['312.1',singlequote,"312",'',''],
+    ['312.1',['\\'],"312.1.e",'',''],
+    ['312.1.e','any',"312.1",'valuepush',''],
     ['312.1','any',"312.1",'valuepush',''],
 
     ['312',doublequote,"312.4",'',''],
     ['312.4',doublequote,"312",'',''],
+    ['312.4',['\\'],"312.4.e",'',''],
+    ['312.4.e','any',"312.4",'valuepush',''],
     ['312.4','any',"312.4",'valuepush',''],
     
     ['312',"any","312.2",'valuepush',''],
@@ -397,9 +409,13 @@ rule=[
     ['359.2','any',"359.3",'pass',''],
     ['359.3',singlequote,"359.4",'',''],
         ['359.4',singlequote,"359.3",'','value'],
+        ['359.4',['\\'],"359.4.e",'',''],   
+        ['359.4.e','any',"359.4",'valpush',''],   
         ['359.4','any',"359.4",'valpush',''],   
     ['359.3',doublequote,"359.41",'',''],
         ['359.41',doublequote,"359.3",'','value'],
+        ['359.41',['\\'],"359.41.e",'',''],   
+        ['359.41.e','any',"359.41",'valpush',''],   
         ['359.41','any',"359.41",'valpush',''],   
     ['359.3',[','],"357.5",'','value'],
     ['359.3',string.whitespace,"359.5",'',''],
@@ -433,9 +449,13 @@ rule=[
         ['367.2','any',"367",'pass',''],
     ['367',singlequote,"367.3",'push',''],
         ['367.3',singlequote,"367",'push',''],
+        ['367.3',['\\'],"367.3.e",'',''],
+        ['367.3.e','any',"367.3",'push',''],
         ['367.3','any',"367.3",'push',''],
     ['367',doublequote,"367.31",'push',''],
         ['367.31',doublequote,"367",'push',''],
+        ['367.31',['\\'],"367.31.e",'',''],
+        ['367.31.e','any',"367.31",'push',''],
         ['367.31','any',"367.31",'push',''],
     
     ['367',operator,"367",'push',''],
@@ -496,9 +516,13 @@ rule=[
         ['424.2','any',"424",'pass',''],
     ['424',singlequote,"424.3",'push',''],
         ['424.3',singlequote,"424",'push',''],
+        ['424.3',['\\'],"424.3.e",'',''],
+        ['424.3.e','any',"424.3",'push',''],
         ['424.3','any',"424.3",'push',''],
     ['424',doublequote,"424.31",'push',''],
         ['424.31',doublequote,"424",'push',''],
+        ['424.31',['\\'],"424.31.e",'',''],
+        ['424.31.e','any',"424.31",'push',''],
         ['424.31','any',"424.31",'push',''],
     
     ['424',operator,"424",'push',''],
